@@ -4,7 +4,6 @@ try:
     import cPickle as pickle
 except ImportError:
     import pickle
-import sys
 
 
 def find_nearest_pickleable_exception(exc):
@@ -13,7 +12,7 @@ def find_nearest_pickleable_exception(exc):
     not go below :exc:`Exception` (i.e. it skips :exc:`Exception`,
     :class:`BaseException` and :class:`object`). If that happens
     you should use :exc:`UnpickleableException` instead.
-  
+
     :param exc: An exception instance.
 
     :returns: the nearest exception if it's not :exc:`Exception` or below,
@@ -39,11 +38,11 @@ def find_nearest_pickleable_exception(exc):
 
 class UnpickleableExceptionWrapper(Exception):
     """Wraps unpickleable exceptions.
-   
+
     :param exc_module: see :attr:`exc_module`.
 
     :param exc_cls_name: see :attr:`exc_cls_name`.
-    
+
     :param exc_args: see :attr:`exc_args`
 
     .. attribute:: exc_module
@@ -80,12 +79,13 @@ class UnpickleableExceptionWrapper(Exception):
 class BaseBackend(object):
     """The base backend class. All backends should inherit from this."""
 
+    capabilities = []
     UnpickleableExceptionWrapper = UnpickleableExceptionWrapper
 
     def store_result(self, task_id, result, status):
         """Store the result and status of a task."""
         raise NotImplementedError(
-                "Backends must implement the store_result method")
+                "store_result is not supported by this backend.")
 
     def mark_as_done(self, task_id, result):
         """Mark task as successfully executed."""
@@ -96,11 +96,13 @@ class BaseBackend(object):
         return self.store_result(task_id, exc, status="FAILURE")
 
     def create_exception_cls(self, name, module, parent=None):
+        """Dynamically create an exception class."""
         if not parent:
             parent = Exception
         return type(name, (parent, ), {"__module__": module})
 
     def prepare_exception(self, exc):
+        """Prepare exception for serialization."""
         nearest = find_nearest_pickleable_exception(exc)
         if nearest:
             return nearest
@@ -115,8 +117,9 @@ class BaseBackend(object):
             return excwrapper
         else:
             return exc
-    
+
     def exception_to_python(self, exc):
+        """Convert serialized exception to Python exception."""
         if isinstance(exc, UnpickleableExceptionWrapper):
             exc_cls = self.create_exception_cls(exc.exc_cls_name,
                                                 exc.exc_module)
@@ -130,7 +133,7 @@ class BaseBackend(object):
     def get_status(self, task_id):
         """Get the status of a task."""
         raise NotImplementedError(
-                "Backends must implement the get_status method")
+                "get_status is not supported by this backend.")
 
     def prepare_result(self, result):
         """Prepare result for storage."""
@@ -141,7 +144,7 @@ class BaseBackend(object):
     def get_result(self, task_id):
         """Get the result of a task."""
         raise NotImplementedError(
-                "Backends must implement the get_result method")
+                "get_result is not supported by this backend.")
 
     def is_done(self, task_id):
         """Returns ``True`` if the task was successfully executed."""
