@@ -31,6 +31,8 @@ class Backend(BaseBackend):
     tyrant_host = None
     tyrant_port = None
 
+    capabilities = ["ResultStore"]
+
     def __init__(self, tyrant_host=None, tyrant_port=None):
         """Initialize Tokyo Tyrant backend instance.
 
@@ -38,15 +40,15 @@ class Backend(BaseBackend):
         :setting:`TT_HOST` or :setting:`TT_PORT` is not set.
 
         """
-        self.tyrant_host = kwargs.get("tyrant_host",
-                            getattr(settings, "TT_HOST", self.tyrant_host))
-        self.tyrant_port = kwargs.get("tyrant_port",
-                            getattr(settings, "TT_PORT", self.tyrant_port))
+        self.tyrant_host = tyrant_host or \
+                            getattr(settings, "TT_HOST", self.tyrant_host)
+        self.tyrant_port = tyrant_port or \
+                            getattr(settings, "TT_PORT", self.tyrant_port)
         if not self.tyrant_host or not self.tyrant_port:
             raise ImproperlyConfigured(
                 "To use the Tokyo Tyrant backend, you have to "
                 "set the TT_HOST and TT_PORT settings in your settings.py")
-        super(Backend, self).__init__(*args, **kwargs)
+        super(Backend, self).__init__()
         self._cache = {}
 
     def get_server(self):
@@ -55,6 +57,7 @@ class Backend(BaseBackend):
         return pytyrant.PyTyrant.open(self.tyrant_host, self.tyrant_port)
 
     def _cache_key(self, task_id):
+        """Get the cache key for a task by id."""
         return "celery-task-meta-%s" % task_id
 
     def store_result(self, task_id, result, status):
@@ -68,11 +71,11 @@ class Backend(BaseBackend):
 
     def get_status(self, task_id):
         """Get the status for a task."""
-        return self._get_task_meta_for(self, task_id)["status"]
+        return self._get_task_meta_for(task_id)["status"]
 
     def get_result(self, task_id):
         """Get the result of a task."""
-        meta = self._get_task_meta_for(self, task_id)
+        meta = self._get_task_meta_for(task_id)
         if meta["status"] == "FAILURE":
             return self.exception_to_python(meta["result"])
         else:
@@ -83,6 +86,7 @@ class Backend(BaseBackend):
         return self.get_status(task_id) == "DONE"
 
     def _get_task_meta_for(self, task_id):
+        """Get task metadata for a task by id."""
         if task_id in self._cache:
             return self._cache[task_id]
         meta = self.get_server().get(self._cache_key(task_id))
