@@ -40,12 +40,12 @@ if django_project_dir:
 
 from django.conf import settings
 from celery.platform import PIDFile, daemonize, remove_pidfile
-from celery.log import setup_logger, emergency_error
+from celery.log import emergency_error
 from celery.conf import LOG_LEVELS, DAEMON_LOG_FILE, DAEMON_LOG_LEVEL
 from celery.conf import DAEMON_CONCURRENCY, DAEMON_PID_FILE
 from celery.conf import QUEUE_WAKEUP_AFTER
 from celery import discovery
-from celery.worker import TaskDaemon
+from celery.worker import WorkController
 import traceback
 import optparse
 import atexit
@@ -54,6 +54,7 @@ import atexit
 def main(concurrency=DAEMON_CONCURRENCY, daemon=False,
         loglevel=DAEMON_LOG_LEVEL, logfile=DAEMON_LOG_FILE,
         pidfile=DAEMON_PID_FILE, queue_wakeup_after=QUEUE_WAKEUP_AFTER):
+    """Run the celery daemon."""
     if settings.DATABASE_ENGINE == "sqlite3" and concurrency > 1:
         import warnings
         warnings.warn("The sqlite3 database engine doesn't support "
@@ -70,10 +71,11 @@ def main(concurrency=DAEMON_CONCURRENCY, daemon=False,
         logfile = None # log to stderr when not running as daemon.
 
     discovery.autodiscover()
-    celeryd = TaskDaemon(concurrency=concurrency,
+    celeryd = WorkController(concurrency=concurrency,
                                loglevel=loglevel,
                                logfile=logfile,
-                               queue_wakeup_after=queue_wakeup_after)
+                               queue_wakeup_after=queue_wakeup_after,
+                               is_detached=daemon)
     try:
         celeryd.run()
     except Exception, e:
@@ -81,28 +83,33 @@ def main(concurrency=DAEMON_CONCURRENCY, daemon=False,
                             e.__class__, e, traceback.format_exc()))
 
 
-def parse_options(arguments):
-    parser = optparse.OptionParser()
-    parser.add_option('-c', '--concurrency', default=DAEMON_CONCURRENCY,
+OPTION_LIST = (
+    optparse.make_option('-c', '--concurrency', default=DAEMON_CONCURRENCY,
             action="store", dest="concurrency", type="int",
-            help="Number of child processes processing the queue.")
-    parser.add_option('-f', '--logfile', default=DAEMON_LOG_FILE,
+            help="Number of child processes processing the queue."),
+    optparse.make_option('-f', '--logfile', default=DAEMON_LOG_FILE,
             action="store", dest="logfile",
-            help="Path to log file.")
-    parser.add_option('-l', '--loglevel', default=DAEMON_LOG_LEVEL,
+            help="Path to log file."),
+    optparse.make_option('-l', '--loglevel', default=DAEMON_LOG_LEVEL,
             action="store", dest="loglevel",
-            help="Choose between DEBUG/INFO/WARNING/ERROR/CRITICAL/FATAL.")
-    parser.add_option('-p', '--pidfile', default=DAEMON_PID_FILE,
+            help="Choose between DEBUG/INFO/WARNING/ERROR/CRITICAL/FATAL."),
+    optparse.make_option('-p', '--pidfile', default=DAEMON_PID_FILE,
             action="store", dest="pidfile",
-            help="Path to pidfile.")
-    parser.add_option('-w', '--wakeup-after', default=QUEUE_WAKEUP_AFTER,
+            help="Path to pidfile."),
+    optparse.make_option('-w', '--wakeup-after', default=QUEUE_WAKEUP_AFTER,
             action="store", dest="queue_wakeup_after",
             help="If the queue is empty, this is the time *in seconds* the "
                  "daemon sleeps until it wakes up to check if there's any "
-                 "new messages on the queue.")
-    parser.add_option('-d', '--daemon', default=False,
+                 "new messages on the queue."),
+    optparse.make_option('-d', '--daemon', default=False,
             action="store_true", dest="daemon",
-            help="Run in the background as a daemon.")
+            help="Run in the background as a daemon."),
+)
+
+
+def parse_options(arguments):
+    """Option parsers for the available options to ``celeryd``."""
+    parser = optparse.OptionParser(option_list=OPTION_LIST)
     options, values = parser.parse_args(arguments)
     if not isinstance(options.loglevel, int):
         options.loglevel = LOG_LEVELS[options.loglevel.upper()]
