@@ -3,8 +3,10 @@ from django.conf import settings
 import logging
 
 DEFAULT_AMQP_EXCHANGE = "celery"
-DEFAULT_AMQP_ROUTING_KEY = "celery"
+DEFAULT_AMQP_PUBLISHER_ROUTING_KEY = "celery"
+DEFAULT_AMQP_CONSUMER_ROUTING_KEY = "celery"
 DEFAULT_AMQP_CONSUMER_QUEUE = "celery"
+DEFAULT_AMQP_EXCHANGE_TYPE = "direct"
 DEFAULT_DAEMON_CONCURRENCY = 10
 DEFAULT_QUEUE_WAKEUP_AFTER = 0.3
 DEFAULT_EMPTY_MSG_EMIT_EVERY = 5
@@ -15,7 +17,7 @@ DEFAULT_DAEMON_LOG_FILE = "celeryd.log"
 
 """
 .. data:: LOG_LEVELS
-   
+
     Mapping of log level names to :mod:`logging` module constants.
 
 """
@@ -31,7 +33,7 @@ LOG_LEVELS = {
 
 """
 .. data:: LOG_FORMAT
-   
+
     The format to use for log messages.
     Default is ``[%(asctime)s: %(levelname)s/%(processName)s] %(message)s``
 
@@ -41,7 +43,7 @@ LOG_FORMAT = getattr(settings, "CELERYD_DAEMON_LOG_FORMAT",
 
 """
 .. data:: DAEMON_LOG_FILE
-   
+
     The path to the deamon log file (if not set, ``stderr`` is used).
 
 """
@@ -50,7 +52,7 @@ DAEMON_LOG_FILE = getattr(settings, "CELERYD_LOG_FILE",
 
 """
 .. data:: DAEMON_LOG_LEVEL
-   
+
     Celery daemon log level, can be any of ``DEBUG``, ``INFO``, ``WARNING``,
     ``ERROR``, ``CRITICAL``, or ``FATAL``. See the :mod:`logging` module
     for more information.
@@ -61,7 +63,7 @@ DAEMON_LOG_LEVEL = LOG_LEVELS[getattr(settings, "CELERYD_DAEMON_LOG_LEVEL",
 
 """
 .. data:: QUEUE_WAKEUP_AFTER
-   
+
     The time (in seconds) the celery worker should sleep when there's
     no messages left on the queue. After the time is slept, the worker
     wakes up and checks the queue again.
@@ -72,7 +74,7 @@ QUEUE_WAKEUP_AFTER = getattr(settings, "CELERYD_QUEUE_WAKEUP_AFTER",
 
 """
 .. data:: EMPTY_MSG_EMIT_EVERY
-   
+
     How often the celery daemon should write a log message saying there are no
     messages in the queue. If this is ``None`` or ``0``, it will never print
     this message.
@@ -83,7 +85,7 @@ EMPTY_MSG_EMIT_EVERY = getattr(settings, "CELERYD_EMPTY_MSG_EMIT_EVERY",
 
 """
 .. data:: DAEMON_PID_FILE
-   
+
     Full path to the daemon pidfile.
 
 """
@@ -92,7 +94,7 @@ DAEMON_PID_FILE = getattr(settings, "CELERYD_PID_FILE",
 
 """
 .. data:: DAEMON_CONCURRENCY
-   
+
     The number of concurrent worker processes, executing tasks simultaneously.
 
 """
@@ -108,20 +110,57 @@ DAEMON_CONCURRENCY = getattr(settings, "CELERYD_CONCURRENCY",
 AMQP_EXCHANGE = getattr(settings, "CELERY_AMQP_EXCHANGE",
                         DEFAULT_AMQP_EXCHANGE)
 
-"""
-.. data:: AMQP_ROUTING_KEY
-   
-    The AMQP routing key.
 
 """
-AMQP_ROUTING_KEY = getattr(settings, "CELERY_AMQP_ROUTING_KEY",
-                           DEFAULT_AMQP_ROUTING_KEY)
+.. data:: AMQP_EXCHANGE_TYPE
+
+The type of exchange. If the exchange type is ``direct``, all messages
+receives all tasks. However, if the exchange type is ``topic``, you can
+route e.g. some tasks to one server, and others to the rest.
+See `Exchange types and the effect of bindings`_.
+
+.. _`Exchange types and the effect of bindings`: http://bit.ly/wpamqpexchanges
+
+"""
+AMQP_EXCHANGE_TYPE = getattr(settings, "CELERY_AMQP_EXCHANGE_TYPE",
+                        DEFAULT_AMQP_EXCHANGE_TYPE)
+
+"""
+.. data:: AMQP_PUBLISHER_ROUTING_KEY
+
+    The default AMQP routing key used when publishing tasks.
+
+"""
+AMQP_PUBLISHER_ROUTING_KEY = getattr(settings,
+                                "CELERY_AMQP_PUBLISHER_ROUTING_KEY",
+                                DEFAULT_AMQP_PUBLISHER_ROUTING_KEY)
+
+"""
+.. data:: AMQP_CONSUMER_ROUTING_KEY
+
+    The AMQP routing key used when consuming tasks.
+
+"""
+AMQP_CONSUMER_ROUTING_KEY = getattr(settings,
+                                "CELERY_AMQP_CONSUMER_ROUTING_KEY",
+                                DEFAULT_AMQP_CONSUMER_ROUTING_KEY)
 
 """
 .. data:: AMQP_CONSUMER_QUEUE
-   
+
     The name of the AMQP queue.
 
 """
 AMQP_CONSUMER_QUEUE = getattr(settings, "CELERY_AMQP_CONSUMER_QUEUE",
                               DEFAULT_AMQP_CONSUMER_QUEUE)
+
+"""
+.. data:: SEND_CELERY_TASK_ERROR_EMAILS
+
+    If set to ``True``, errors in tasks will be sent to admins by e-mail.
+    If unset, it will send the e-mails if DEBUG is False.
+
+"""
+SEND_CELERY_TASK_ERROR_EMAILS = getattr(settings,
+                                        "SEND_CELERY_TASK_ERROR_EMAILS",
+                                        not settings.DEBUG)
