@@ -6,8 +6,12 @@ from django.conf import settings
 SETTING_VARS = (
     ("CELERY_AMQP_CONSUMER_QUEUE", "AMQP_CONSUMER_QUEUE",
         "DEFAULT_AMQP_CONSUMER_QUEUE"),
-    ("CELERY_AMQP_ROUTING_KEY", "AMQP_ROUTING_KEY",
-        "DEFAULT_AMQP_ROUTING_KEY"),
+    ("CELERY_AMQP_PUBLISHER_ROUTING_KEY", "AMQP_PUBLISHER_ROUTING_KEY",
+        "DEFAULT_AMQP_PUBLISHER_ROUTING_KEY"),
+    ("CELERY_AMQP_CONSUMER_ROUTING_KEY", "AMQP_CONSUMER_ROUTING_KEY",
+        "DEFAULT_AMQP_CONSUMER_ROUTING_KEY"),
+    ("CELERY_AMQP_EXCHANGE_TYPE", "AMQP_EXCHANGE_TYPE",
+        "DEFAULT_AMQP_EXCHANGE_TYPE"),
     ("CELERY_AMQP_EXCHANGE", "AMQP_EXCHANGE",
         "DEFAULT_AMQP_EXCHANGE"),
     ("CELERYD_CONCURRENCY", "DAEMON_CONCURRENCY",
