@@ -1,6 +1,6 @@
 """celery.views"""
-from django.http import Http404, HttpResponse
-from celery.task import is_done
+from django.http import HttpResponse
+from celery.task import is_done, delay_task
 from celery.result import AsyncResult
 import simplejson
 
@@ -16,7 +16,7 @@ def task_status(request, task_id):
     async_result = AsyncResult(task_id)
     response_data = {"task": {
                         "id": task_id,
-                        "status": async_result.get_status(),
-                        "result": async_result.get_result(),
+                        "status": async_result.status,
+                        "result": async_result.result,
     }}
     return HttpResponse(simplejson.dumps(response_data))
